#include "testlib.h"
#include <queue>
#include <vector>
#include <algorithm>

using namespace std;

constexpr int limit = 1000000;

vector<int> n(3);
vector<int> a(3);

int sum;

struct state;

state transfer(vector<int> const &values, int from, int to);

struct state {

public:

    int s;
    int i, j;
    bool full;

    state(int s, int i, int j, bool full) : s(s), i(i), j(j), full(full) {};

    state move(int from, int to) const {
        vector<int> values = get_values();
        return transfer(values, from, to);
    }

    vector<int> get_values() const {
        vector<int> values(3);
        values[i] = s;
        values[j] = full ? n[j] : 0;
        values[3 - i - j] = sum - values[i] - values[j];
        return values;
    }

    int st() const {
        return 4 * i + ((2 + j - i) % 3) * 2 + (full ? 1 : 0);
    };

    static state from_status(int s, int status) {
        int i = status / 4;
        int j = (i + (status % 4) / 2 + 1) % 3;
        return state{s, i, j, status % 2 == 1};
    }

};

state transfer(vector<int> const &values, int from, int to) {
    if (values[from] < n[to] - values[to]) {
        return state{values[3 - from - to], 3 - from - to, from, false};
    } else {
        return state{values[3 - from - to], 3 - from - to, to, true};
    }
}

state solve() {

    sum = a[0] + a[1] + a[2];
    /*
     * dp[s][i][j][flag] - в i-м баке s, j-й полный если flag, иначе пустой
     * sum * 3 * 2 * 2
     */
    vector<vector<int>> dp(sum + 1, vector<int>(12, sum * 13));
    queue<pair<int, int>> q;

    for (int i = 0; i < 3; i++) {
        for (int ij = 1; ij < 3; ij++) {
            int j = (i + ij) % 3;
            state s = transfer(a, i, j);

            int st = s.st();
            dp[s.s][st] = 1;
            q.emplace(s.s, st);
        }
    }

    while (!q.empty()) {
        auto f = q.front();
        q.pop();
        state fs = state::from_status(f.first, f.second);
        int d = dp[f.first][f.second];

        for (int i = 0; i < 3; i++) {
            for (int ij = 1; ij < 3; ij++) {
                int j = (i + ij) % 3;
                state ns = fs.move(i, j);

                int st = ns.st();
                if (dp[ns.s][st] > d + 1) {
                    dp[ns.s][st] = d + 1;
                    q.emplace(ns.s, st);
                }
            }
        }
    }

    int res = 0;
    state ans(0, 0, 0, false);
    for (int s = 0; s < dp.size(); s++) {
        for (int st = 0; st < 12; st++) {
            if (dp[s][st] != sum * 13 && dp[s][st] > res) {
                res = dp[s][st];
                ans = state::from_status(s, st);
            }
        }
    }
    return ans;

}

int main(int argc, char *argv[]) {

    registerGen(argc, argv, 1);

    if (argc <= 3) {
        int nn = atoi(argv[1]);
        n[0] = rnd.next(1, nn);
        n[1] = rnd.next(1, nn);
        n[2] = rnd.next(1, nn);
    } else {
        n[0] = atoi(argv[1]);
        n[1] = atoi(argv[2]);
        n[2] = atoi(argv[3]);
    }

    if (argc < 6) {
        a[0] = rnd.next(0, n[0]);
        a[1] = rnd.next(0, n[1]);
        a[2] = rnd.next(0, n[2]);
    } else {
        a[0] = atoi(argv[4]);
        a[1] = atoi(argv[5]);
        a[2] = atoi(argv[6]);
    }

    vector<int> t = solve().get_values();
    for (int i = 0; i < 3; i++) {
        if (rnd.next(2)) {
            swap(t[i], t[(i + 1) % 3]);
        }
    }

    println(n[0], n[1], n[2]);
    println(a[0], a[1], a[2]);
    println(t[0], t[1], t[2]);

}