#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>

using namespace std;

vector<unsigned int> n(3);
vector<unsigned int> a(3);
vector<unsigned int> b(3);

unsigned int sum;

struct state;

state transfer(vector<unsigned int> const &values, unsigned int from, unsigned int to);

struct state {

public:

    unsigned int s;
    unsigned int i, j;
    bool full;

    state(unsigned int s, unsigned int i, unsigned int j, bool full) : s(s), i(i), j(j), full(full) {};

    state move(unsigned int from, unsigned int to) const {
        vector<unsigned int> values = get_values();
        return transfer(values, from, to);
    }

    vector<unsigned int> get_values() const {
        vector<unsigned int> values(3);
        values[i] = s;
        values[j] = full ? n[j] : 0;
        values[3 - i - j] = sum - values[i] - values[j];
        return values;
    }

    unsigned int st() const {
        return 4 * i + ((2 + j - i) % 3) * 2 + (full ? 1 : 0);
    };

    static state from_status(unsigned int s, unsigned int status) {
        unsigned int i = status / 4;
        unsigned int j = (i + (status % 4) / 2 + 1) % 3;
        return state{s, i, j, status % 2 == 1};
    }

};

state transfer(vector<unsigned int> const &values, unsigned int from, unsigned int to) {
    if (values[from] < n[to] - values[to]) {
        return state{values[3 - from - to], 3 - from - to, from, false};
    } else {
        return state{values[3 - from - to], 3 - from - to, to, true};
    }
}

bool check_initial() {
    for (unsigned int i = 0; i < 3; i++) {
        for (unsigned int ij = 1; ij < 3; ij++) {
            unsigned int j = (i + ij) % 3;
            if (a[0] == b[i] && a[1] == b[j] && a[2] == b[3 - i - j]) {
                return true;
            }
        }
    }
    return false;
}

bool check(state const &s) {
    vector<unsigned int> values = s.get_values();
    sort(values.begin(), values.end());
    return values[0] == b[0] && values[1] == b[1] && values[2] == b[2];
}

int main() {

    cin >> n[0] >> n[1] >> n[2]
        >> a[0] >> a[1] >> a[2]
        >> b[0] >> b[1] >> b[2];
    sort(b.begin(), b.end());

    if (check_initial()) {
        cout << "0\n";
        return 0;
    }

    sum = a[0] + a[1] + a[2];
    /*
     * dp[s][i][j][flag] - в i-м баке s, j-й полный если flag, иначе пустой
     * sum * 3 * 2 * 2
     */
    vector<vector<unsigned int>> dp(sum + 1, vector<unsigned int>(12, sum * 13));
    queue<pair<unsigned int, unsigned int>> q;

    for (unsigned int i = 0; i < 3; i++) {
        for (unsigned int ij = 1; ij < 3; ij++) {
            unsigned int j = (i + ij) % 3;
            state s = transfer(a, i, j);

            unsigned int st = s.st();
            dp[s.s][st] = 1;
            q.emplace(s.s, st);
        }
    }

    while (!q.empty()) {
        auto f = q.front();
        q.pop();
        state fs = state::from_status(f.first, f.second);
        unsigned int d = dp[f.first][f.second];

        if (check(fs)) {
            cout << d << '\n';
            return 0;
        }

        for (unsigned int i = 0; i < 3; i++) {
            for (unsigned int ij = 1; ij < 3; ij++) {
                unsigned int j = (i + ij) % 3;
                state ns = fs.move(i, j);

                unsigned int st = ns.st();
                if (dp[ns.s][st] > d + 1) {
                    dp[ns.s][st] = d + 1;
                    q.emplace(ns.s, st);
                }
            }
        }
    }

    cout << "-1\n";

}