#include <iostream>
#include <vector>
#include <set>
#include <limits>

using namespace std;

unsigned int n;
vector<long long> values;

struct segment {
    unsigned int start;
    unsigned int end;
    unsigned int skip;

    segment(unsigned int start, unsigned int end, unsigned int skip) :
            start(start), end(end), skip(skip) {}

    segment(unsigned int i) : start(i), end(i), skip(i) {}

    segment(segment const &other) = default;

    bool operator<(segment const &other) const {
        return start < other.start;
    }

    bool operator==(segment const &other) const {
        return start == other.start;
    }

    unsigned int length() const {
        return skip - start + 1;
    }
};

struct length_comparator {
    bool operator()(segment const &s1, segment const &s2) {
        if (s1.length() != s2.length()) {
            return s1.length() > s2.length();
        } else {
            return s1 < s2;
        }
    }
};

set<segment> segments;
set<segment, length_comparator> l_segments;

unsigned int get() {
    return l_segments.begin()->length();
}

void erase(segment const &s) {
    segments.erase(s);
    l_segments.erase(s);
}

void insert(unsigned int start, unsigned int end, unsigned int skip) {
    segment s(start, end, skip);
    segments.insert(s);
    l_segments.insert(s);
}

void update(unsigned int i, long long x) {
    if (n < 3) {
        values[i] = x;
        return;
    }

    if (i == n - 1) {
        long long left = values[n - 2];
        if (left > values[i] != left > x) {
            segment last = *(--segments.end());
            erase(last);
            if (last.end < n - 2) {
                insert(last.start, last.end, n - 2);
                insert(n - 2, n - 1, n - 1);
            } else if (last.end == n - 2) {
                insert(last.start, n - 1, n - 1);
            } else if (last.start < n - 2) {
                insert(last.start, n - 2, n - 1);
            } else {
                segment prev = *(--segments.end());
                erase(prev);
                insert(prev.start, prev.end, n - 1);
            }
        }
        values[i] = x;
        return;
    }

    if (i == 0) {
        long long right = values[1];
        if (right > values[i] != right > x) {
            segment first = *segments.begin();
            erase(first);
            if (first.skip == 1) {
                segment next = *segments.begin();
                erase(next);
                insert(0, next.end, next.skip);
            } else if (first.end <= 1) {
                insert(0, 1 - first.end, first.skip);
            } else {
                insert(0, 0, 1);
                insert(1, first.end, first.skip);
            }
        }
        values[i] = x;
        return;
    }

    long long left = values[i - 1];
    long long right = values[i + 1];
    if (left > values[i] == left > x && right > values[i] == right > x) {
        values[i] = x;
        return;
    } else {
        auto it = --segments.upper_bound(i);
        segment cur = *it;
        segment prev = it != segments.begin() ? *(--set<segment>::iterator(it)) : segment(-1);
        segment next = it != --segments.end() ? *(++set<segment>::iterator(it)) : segment(n + 1);
        erase(cur);
        if (i == cur.start) {
            erase(prev);
            if (x < left) {
                if (cur.end == i + 1) {
                    insert(prev.start, prev.end, cur.skip);
                } else {
                    insert(prev.start, prev.end, i + 1);
                    insert(i + 1, cur.end, cur.skip);
                }
            } else if (x < right) {
                if (prev.end < i - 1) {
                    insert(prev.start, prev.end, i - 1);
                    insert(i - 1, cur.end, cur.skip);
                } else {
                    insert(prev.start, cur.end, cur.skip);
                }
            } else {
                if (prev.end == i - 1 && cur.end == i + 1) {
                    insert(prev.start, i, cur.skip);
                } else if (prev.end == i - 1) {
                    insert(prev.start, i, i + 1);
                    insert(i + 1, cur.end, cur.skip);
                } else if (cur.end == i + 1) {
                    insert(prev.start, prev.end, i - 1);
                    insert(i - 1, i, cur.skip);
                } else {
                    insert(prev.start, prev.end, i - 1);
                    insert(i - 1, i, i + 1);
                    insert(i + 1, cur.end, cur.skip);
                }
            }
        } else {
            if (i == cur.start + 1 && i == cur.skip - 1 && i == cur.end) {
                if (x < min(left, right)) {
                    if (prev.start != -1) {
                        erase(prev);
                        insert(prev.start, prev.end, i);
                    } else {
                        insert(0, 0, 1);
                    }
                    if (next.start != n + 1) {
                        erase(next);
                        insert(i, next.end, next.skip);
                    } else {
                        insert(n - 2, n - 1, n - 1);
                    }
                } else if (x > right) {
                    if (prev.start != -1) {
                        erase(prev);
                        insert(prev.start, prev.end, i + 1);
                    } else {
                        insert(0, 0, 2);
                    }
                } else {
                    if (next.start != n + 1) {
                        erase(next);
                        insert(i - 1, next.end, next.skip);
                    } else {
                        insert(n - 3, n - 1, n - 1);
                    }
                }
                values[i] = x;
                return;
            }
            if (prev.start != -1 && i == cur.start + 1 && x < left) {
                erase(prev);
                if (i == cur.end && x > right) {
                    insert(prev.start, prev.end, cur.skip);
                } else if (i == cur.end) {
                    insert(prev.start, prev.end, i);
                    insert(i, i + 1, cur.skip);
                } else {
                    insert(prev.start, prev.end, i);
                    insert(i, cur.end, cur.skip);
                }
                values[i] = x;
                return;
            }
            if (next.start != n + 1 && i == cur.skip - 1 && x < right) {
                erase(next);
                if (i == cur.end && x > left) {
                    insert(cur.start, next.end, next.skip);
                } else if (i == cur.end) {
                    insert(cur.start, i - 1, i);
                    insert(i, next.end, next.skip);
                } else {
                    insert(i, next.end, next.skip);
                    insert(cur.start, cur.end, i);
                }
                values[i] = x;
                return;
            }

            if (i < cur.end) {
                if (i == cur.end - 1 && x > values[i]) {
                    insert(cur.start, cur.end - 1, cur.skip);
                } else {
                    unsigned int middle = x < values[i] ? i : i + 1;
                    insert(cur.start, middle - 1, middle);
                    insert(middle, cur.end, cur.skip);
                }
            } else if (i > cur.end) {
                if (i == cur.end + 1 && x > values[i]) {
                    insert(cur.start, cur.end + 1, cur.skip);
                } else {
                    unsigned int middle = x < values[i] ? i + 1 : i;
                    insert(cur.start, cur.end, middle - 1);
                    insert(middle - 1, middle, cur.skip);
                }
            } else {
                if (x < min(left, right)) {
                    insert(cur.start, cur.end - 1, cur.end);
                    insert(cur.end, cur.end + 1, cur.skip);
                } else if (values[cur.end - 1] > values[cur.end + 1]) {
                    insert(cur.start, cur.end - 1, cur.skip);
                } else {
                    insert(cur.start, cur.end + 1, cur.skip);
                }
            }
        }
        values[i] = x;
    }
}

int main() {

    cin >> n;
    values.resize(n);

    for (unsigned int i = 0; i < n; i++) {
        cin >> values[i];
    }
    unsigned int i = 0;
    while (i + 1 < n) {
        unsigned int start = i;
        while (i + 1 < n && values[i + 1] > values[i]) {
            i++;
        }
        unsigned int end = i;
        while (i + 1 < n && values[i + 1] < values[i]) {
            i++;
        }
        insert(start, end, i);
    }

    unsigned int q;
    cin >> q;

    unsigned int x;
    long long y;
    for (unsigned int t = 0; t < q; t++) {
        cin >> x >> y;
        x--;
        update(x, y);
#ifndef LOCAL
        cout << get() << '\n';
#else
        cout << t + 1 << ": " << x << ' ' << y << '\n';
        for (auto const &c : values) {
//            std::cout << c << ' ';
            std::cout << c / ((long long) 1e5) << ' ';
        }
        std::cout << '\n';
        for (auto const &s : segments) {
            std::cout << "(" << s.start << "," << s.end << "," << s.skip << ") ";
        }
        std::cout << '\n';
#endif
    }

}