//
// Created by kgrug on 05.11.2020.
//

#include "testlib.h"
#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <bitset>

using namespace std;

vector<int> getRandomShufflePrefix(int size, int count) {
    vector<pair<int, int>> tmp(size);
    for (int i = 0; i < size; i++) {
        tmp[i].first = rnd.next(0, 100000);
        tmp[i].second = i;
    }
    std::sort(tmp.begin(), tmp.end());
    vector<int> result(count);
    for (int i = 0; i < count; i++) {
        result[i] = tmp[i].second;
    }
    return result;
}

int main(int argc, char *argv[]) {
    registerGen(argc, argv, 1);

    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

    int k = stoi(argv[1]);
    int n = stoi(argv[2]);
    int m = k - n;

    int p = stoi(argv[3]);
    p = min(p, n);

    cout << k << " " << m << '\n';

    vector<vector<bool>> table(n, vector<bool>(m));
    for (int column = 0; column < m; column++) {

        vector<int> selected = getRandomShufflePrefix(n, p);
        for (int ind : selected) {
            table[ind][column] = true;
        }

    }

    vector<int> players_shuffle = getRandomShufflePrefix(k, k);
    vector<int> killers(n);
    vector<int> victims(m);
    for (int i = 0; i < n; i++) {
        killers[i] = players_shuffle[i];
    }
    for (int i = n; i < k; i++) {
        victims[i - n] = players_shuffle[i];
    }

    set<int> alive_players;
    for (int i = 0; i < k; i++) {
        alive_players.insert(i);
    }

    for (int night_num = 0; night_num < m; night_num++) {
        int night_victim = victims[night_num];

        set<pair<int, int>> meetings;
        set<pair<int, int>> ban_meetings;

        for (int i = 0; i < n; i++) {
            int curr_killer = killers[i];
            if (table[i][night_num]) {
                meetings.insert(make_pair(curr_killer, night_victim));
                meetings.insert(make_pair(night_victim, curr_killer));
            } else {
                ban_meetings.insert(make_pair(curr_killer, night_victim));
                ban_meetings.insert(make_pair(night_victim, curr_killer));
            }
        }

        vector<pair<int, int>> all_meetings;
        for (int player1 : alive_players) {
            for (int player2 : alive_players) {
                if (player1 < player2) {
                    pair<int, int> x = make_pair(player1, player2);

                    if (ban_meetings.count(x) == 0) {
                        all_meetings.push_back(x);
                    }
                }
            }
        }

        int all_meet_size = all_meetings.size();
        int all_meet_count = (4 * all_meet_size) / 5;
        vector<int> meet_shuffle = getRandomShufflePrefix(
                all_meet_size, all_meet_count);

        for (int ind : meet_shuffle) {
            pair<int, int> x = all_meetings[ind];
            pair<int, int> inv_x = make_pair(x.second, x.first);

            meetings.insert(x);
            meetings.insert(inv_x);
        }

        vector<vector<int>> night_graph(k);
        for (pair<int, int> meet : meetings) {
            night_graph[meet.first].push_back(meet.second);
        }

        for (int player1 = 0; player1 < k; player1++) {
            if (alive_players.count(player1) == 0) {
                continue;
            }

            cout << player1 + 1 << " " << night_graph[player1].size() << '\n';

            for (int j = 0; j < night_graph[player1].size(); j++) {
                int player2 = night_graph[player1][j];

                cout << player2 + 1;
                if (j != (night_graph[player1].size() - 1)) {
                    cout << " ";
                }
            }
            cout << '\n';

        }

        cout << night_victim + 1 << '\n';

        alive_players.erase(night_victim);
    }

}