//
// Created by kgrug on 05.11.2020.
//

#include "testlib.h"
#include <vector>
#include <set>
#include <map>
#include <bitset>

using namespace std;

bool check_graph(vector<vector<int>> & graph) {
    for (int x = 0; x < graph.size(); x++) {
        for (int i = 0; i < graph[x].size(); i++) {
            int y = graph[x][i];

            bool flag = false;
            for (int x2 : graph[y]) {
                if (x == x2) {
                    flag = true;
                }
            }

            if (!flag) {
                return false;
            }
        }
    }
    return true;
}

int main(int argc, char *argv[]) {
    registerValidation(argc, argv);

    constexpr int max_m = 200;

    int k = inf.readInt(2, 200, "k");
    inf.readSpace();
    int m = inf.readInt(1, 199, "m");
    inf.readEoln();

    ensuref(k > m,
            "players should be more than nights");
    ensuref((k - m <= 15),
            "too much complexity: 2^(%d) * %d * %d", k - m, k, m);

    map<int, bitset<max_m>> table;
    vector<vector<int>> victims_suspect;

    set<int> victims;
    set<int> alive_players;
    for (int i = 1; i <= k; i++) {
        alive_players.insert(i);
    }
    int k2 = k;

    for (int i = 0; i < m; i++) {

        set<int> curr_alive_players;

        vector<vector<int>> night_graph(k);

        for (int j = 0; j < k2; j++) {

            int n = inf.readInt(1, k, "n");
            inf.readSpace();
            int count = inf.readInt(0, k2 - 1, "count");

            ensuref(victims.count(n) == 0,
                    "the victim can't play any further");
            ensuref(curr_alive_players.count(n) == 0,
                    "the player has already been described");

            curr_alive_players.insert(n);

            inf.readEoln();

            for (int w = 0; w < count; w++) {
                if (w > 0) {
                    inf.readSpace();
                }
                int x = inf.readInt(1, k, "x");
                ensuref(x != n,
                        "the player %d cannot face himself", x);
                ensuref(victims.count(x) == 0,
                        "the victim can't play any further");

                night_graph[n - 1].push_back(x - 1);
            }

            inf.readEoln();

        }

        bool valid_graph = check_graph(night_graph);
        ensuref(valid_graph, "incorrect meeting graph");

        int victim = inf.readInt(1, k, "victim");

        ensuref(curr_alive_players.size() == alive_players.size(),
                "not all live players have been described");
        ensuref(victims.count(victim) == 0,
                "the victim has already been");

        victims_suspect.push_back(night_graph[victim - 1]);

        victims.insert(victim);
        alive_players.erase(victim);

        inf.readEoln();

        k2--;
    }

    ensuref(victims_suspect.size() == m, "unexpected error 1");

    for (int i = 0; i < victims_suspect.size(); i++) {
        for (int j = 0; j < victims_suspect[i].size(); j++) {
            int suspect = victims_suspect[i][j];

            if (alive_players.count(suspect + 1) != 0) {

                if (table.count(suspect) == 0) {
                    bitset<max_m> bs;
                    table.insert(make_pair(suspect, bs));
                }

                table[suspect][i] = true;

            }
        }
    }

    bitset<max_m> res_bs;
    for (auto pair : table) {
        res_bs |= pair.second;
    }
    bool solution_exists = true;
    for (int i = 0; i < m; i++) {
        if (!res_bs[i]) {
            solution_exists = false;
            break;
        }
    }
    
    ensuref(solution_exists, "there is no solution");

    inf.readEof();
}